# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/slashing.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/slashing/v1beta1/slashing.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xf0\x01\n\x14ValidatorSigningInfo\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ConsensusAddressString\x12\x14\n\x0cstart_height\x18\x02 \x01(\x03\x12\x14\n\x0cindex_offset\x18\x03 \x01(\x03\x12?\n\x0cjailed_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x12\n\ntombstoned\x18\x05 \x01(\x08\x12\x1d\n\x15missed_blocks_counter\x18\x06 \x01(\x03:\x04\xe8\xa0\x1f\x01\"\x9f\x03\n\x06Params\x12\x1c\n\x14signed_blocks_window\x18\x01 \x01(\x03\x12U\n\x15min_signed_per_window\x18\x02 \x01(\x0c\x42\x36\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12H\n\x16\x64owntime_jail_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12Z\n\x1aslash_fraction_double_sign\x18\x04 \x01(\x0c\x42\x36\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12W\n\x17slash_fraction_downtime\x18\x05 \x01(\x0c\x42\x36\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01:!\x8a\xe7\xb0*\x1c\x63osmos-sdk/x/slashing/ParamsB3Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.slashing_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types\250\342\036\001'
  _globals['_VALIDATORSIGNINGINFO'].fields_by_name['address']._options = None
  _globals['_VALIDATORSIGNINGINFO'].fields_by_name['address']._serialized_options = b'\322\264-\035cosmos.ConsensusAddressString'
  _globals['_VALIDATORSIGNINGINFO'].fields_by_name['jailed_until']._options = None
  _globals['_VALIDATORSIGNINGINFO'].fields_by_name['jailed_until']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_VALIDATORSIGNINGINFO']._options = None
  _globals['_VALIDATORSIGNINGINFO']._serialized_options = b'\350\240\037\001'
  _globals['_PARAMS'].fields_by_name['min_signed_per_window']._options = None
  _globals['_PARAMS'].fields_by_name['min_signed_per_window']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['downtime_jail_duration']._options = None
  _globals['_PARAMS'].fields_by_name['downtime_jail_duration']._serialized_options = b'\310\336\037\000\230\337\037\001\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['slash_fraction_double_sign']._options = None
  _globals['_PARAMS'].fields_by_name['slash_fraction_double_sign']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['slash_fraction_downtime']._options = None
  _globals['_PARAMS'].fields_by_name['slash_fraction_downtime']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS']._options = None
  _globals['_PARAMS']._serialized_options = b'\212\347\260*\034cosmos-sdk/x/slashing/Params'
  _globals['_VALIDATORSIGNINGINFO']._serialized_start=201
  _globals['_VALIDATORSIGNINGINFO']._serialized_end=441
  _globals['_PARAMS']._serialized_start=444
  _globals['_PARAMS']._serialized_end=859
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.dydxprotocol.stats import query_pb2 as dydxprotocol_dot_stats_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/dydxprotocol.stats.Query/Params',
                request_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.StatsMetadata = channel.unary_unary(
                '/dydxprotocol.stats.Query/StatsMetadata',
                request_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataResponse.FromString,
                )
        self.GlobalStats = channel.unary_unary(
                '/dydxprotocol.stats.Query/GlobalStats',
                request_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsResponse.FromString,
                )
        self.UserStats = channel.unary_unary(
                '/dydxprotocol.stats.Query/UserStats',
                request_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsRequest.SerializeToString,
                response_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Queries the Params.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsMetadata(self, request, context):
        """Queries StatsMetadata.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GlobalStats(self, request, context):
        """Queries GlobalStats.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserStats(self, request, context):
        """Queries UserStats.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'StatsMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsMetadata,
                    request_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataRequest.FromString,
                    response_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataResponse.SerializeToString,
            ),
            'GlobalStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GlobalStats,
                    request_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsRequest.FromString,
                    response_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsResponse.SerializeToString,
            ),
            'UserStats': grpc.unary_unary_rpc_method_handler(
                    servicer.UserStats,
                    request_deserializer=dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsRequest.FromString,
                    response_serializer=dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.stats.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.stats.Query/Params',
            dydxprotocol_dot_stats_dot_query__pb2.QueryParamsRequest.SerializeToString,
            dydxprotocol_dot_stats_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.stats.Query/StatsMetadata',
            dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataRequest.SerializeToString,
            dydxprotocol_dot_stats_dot_query__pb2.QueryStatsMetadataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GlobalStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.stats.Query/GlobalStats',
            dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsRequest.SerializeToString,
            dydxprotocol_dot_stats_dot_query__pb2.QueryGlobalStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.stats.Query/UserStats',
            dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsRequest.SerializeToString,
            dydxprotocol_dot_stats_dot_query__pb2.QueryUserStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.dydxprotocol.vest import tx_pb2 as dydxprotocol_dot_vest_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetVestEntry = channel.unary_unary(
                '/dydxprotocol.vest.Msg/SetVestEntry',
                request_serializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntry.SerializeToString,
                response_deserializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntryResponse.FromString,
                )
        self.DeleteVestEntry = channel.unary_unary(
                '/dydxprotocol.vest.Msg/DeleteVestEntry',
                request_serializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntry.SerializeToString,
                response_deserializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntryResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def SetVestEntry(self, request, context):
        """SetVestEntry sets a VestEntry in state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteVestEntry(self, request, context):
        """DeleteVestEntry deletes a VestEntry from state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetVestEntry': grpc.unary_unary_rpc_method_handler(
                    servicer.SetVestEntry,
                    request_deserializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntry.FromString,
                    response_serializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntryResponse.SerializeToString,
            ),
            'DeleteVestEntry': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteVestEntry,
                    request_deserializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntry.FromString,
                    response_serializer=dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.vest.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def SetVestEntry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.vest.Msg/SetVestEntry',
            dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntry.SerializeToString,
            dydxprotocol_dot_vest_dot_tx__pb2.MsgSetVestEntryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteVestEntry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.vest.Msg/DeleteVestEntry',
            dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntry.SerializeToString,
            dydxprotocol_dot_vest_dot_tx__pb2.MsgDeleteVestEntryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/clob_pair.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/clob/clob_pair.proto\x12\x11\x64ydxprotocol.clob\"-\n\x15PerpetualClobMetadata\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\"A\n\x10SpotClobMetadata\x12\x15\n\rbase_asset_id\x18\x01 \x01(\r\x12\x16\n\x0equote_asset_id\x18\x02 \x01(\r\"\xef\x03\n\x08\x43lobPair\x12\n\n\x02id\x18\x01 \x01(\r\x12K\n\x17perpetual_clob_metadata\x18\x02 \x01(\x0b\x32(.dydxprotocol.clob.PerpetualClobMetadataH\x00\x12\x41\n\x12spot_clob_metadata\x18\x03 \x01(\x0b\x32#.dydxprotocol.clob.SpotClobMetadataH\x00\x12\x1a\n\x12step_base_quantums\x18\x04 \x01(\x04\x12\x19\n\x11subticks_per_tick\x18\x05 \x01(\r\x12#\n\x1bquantum_conversion_exponent\x18\x06 \x01(\x11\x12\x32\n\x06status\x18\x07 \x01(\x0e\x32\".dydxprotocol.clob.ClobPair.Status\"\xaa\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x11\n\rSTATUS_ACTIVE\x10\x01\x12\x11\n\rSTATUS_PAUSED\x10\x02\x12\x16\n\x12STATUS_CANCEL_ONLY\x10\x03\x12\x14\n\x10STATUS_POST_ONLY\x10\x04\x12\x17\n\x13STATUS_INITIALIZING\x10\x05\x12\x1b\n\x17STATUS_FINAL_SETTLEMENT\x10\x06\x42\n\n\x08metadataB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.clob_pair_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_PERPETUALCLOBMETADATA']._serialized_start=56
  _globals['_PERPETUALCLOBMETADATA']._serialized_end=101
  _globals['_SPOTCLOBMETADATA']._serialized_start=103
  _globals['_SPOTCLOBMETADATA']._serialized_end=168
  _globals['_CLOBPAIR']._serialized_start=171
  _globals['_CLOBPAIR']._serialized_end=666
  _globals['_CLOBPAIR_STATUS']._serialized_start=484
  _globals['_CLOBPAIR_STATUS']._serialized_end=654
# @@protoc_insertion_point(module_scope)
